@@ -8,7 +8,6 @@ function should_push_preview(event_path = get(ENV, "GITHUB_EVENT_PATH", nothing)
     pull_request = get(event, "pull_request", nothing)
     pull_request === nothing && return false
     labels = [x["name"] for x in pull_request["labels"]]
-    # https://developer.github.com/v3/activity/events/types/#pullrequestevent
     yes = "push_preview" in labels
     if yes
         @info "Trying to push preview as label `push_preview` is specified." labels
@@ -24,12 +23,12 @@ makedocs(;
     pages=[
         "Home" => "index.md",
     ],
-    repo="https://github.com/tkf/ThreadsX.jl/blob/{commit}{path}#L{line}",
+    warnonly = true,
     sitename="ThreadsX.jl",
     authors="Takafumi Arakaki <aka.tkf@gmail.com>",
 )
 
 deploydocs(;
-    repo="github.com/tkf/ThreadsX.jl",
+    repo="github.com/JuliaFolds2/ThreadsX.jl",
     push_preview = should_push_preview(),
 )
